internal library
Exposes internally used classes, enums, native structs, and helper functions.
Classes
- IAsyncAction
- Represents an asynchronous action. This is the return type for many Windows Runtime asynchronous methods that don't have a result object, and don't report ongoing progress.
- IAsyncInfo
-
Supports asynchronous actions and operations.
IAsyncInfois a base interface forIAsyncAction,IAsyncActionWithProgress<TProgress>,IAsyncOperation<TResult>andIAsyncOperationWithProgress<TResult,TProgress>, each of which support combinations of return type and progress for an asynchronous method. -
IAsyncOperation<
TResult> - Represents an asynchronous operation, which returns a result upon completion. This is the return type for many Windows Runtime asynchronous methods that have results but don't report progress.
- IPropertyValue
- Represents a value in a property store.
-
IReference<
T> - Enables arbitrary enumerations, structures, and delegate types to be used as property values.
- PropertyValue
-
Represents a value in a property store (such as a
PropertySetinstance).
Enums
- AsyncStatus
- Specifies the status of an asynchronous operation.
- PropertyType
- Specifies property value types.