ValueSet class
Implements a map with keys of type String and values of type Object. Object
must be a WinRT PropertyValue or ValueSet. As a PropertyValue, it can
be any type except PropertyType InspectableArray. This limitation exists
to ensure that the value can be serialized; passed by value across a process
boundary.
- Implemented types
- Available extensions
Constructors
- ValueSet()
-
ValueSet.fromPtr(Pointer<
COMObject> ptr)
Properties
Methods
-
add_MapChanged(
Pointer< COMObject> vhnd) → int -
override
-
addRef(
) → int -
Increments the reference count for an interface pointer to a COM object.
inherited
-
cast<
T extends IUnknown> (T creator(Pointer< COMObject> ), String iid) → T -
Available on IUnknown, provided by the IUnknownHelpers extension
Casts this COM object to an interface specified iniid. -
clear(
) → void -
Removes all items from the map.
override
-
detach(
) → void -
Detaches the object from the
Finalizer.inherited -
first(
) → IIterator< IKeyValuePair< String, Object?> > -
Returns an iterator for the items in the collection.
override
-
getIids(
Pointer< Uint32> iidCount, Pointer<Pointer< iids) → intGUID> > -
inherited
-
getRuntimeClassName(
Pointer< IntPtr> className) → int -
inherited
-
getTrustLevel(
Pointer< Int32> trustLevel) → int -
inherited
-
getView(
) → Map< String, Object?> -
Returns an immutable view of the map.
override
-
hasKey(
String key) → bool -
Determines whether the map contains the specified key.
override
-
insert(
String key, Object? value) → bool -
Inserts or replaces an item in the map.
override
-
lookup(
String key) → Object? -
Returns the item at the specified key in the map.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryInterface(
Pointer< GUID> riid, Pointer<Pointer< ppvObject) → intNativeType> > -
Queries a COM object for a pointer to one of its interface; identifying
the interface by a reference to its interface identifier (IID).
inherited
-
release(
) → int -
Decrements the reference count for an interface on a COM object.
inherited
-
remove(
String key) → void -
Removes an item from the map.
override
-
remove_MapChanged(
int token) → void -
override
-
toInterface(
String iid) → Pointer< COMObject> -
Cast an existing COM object to a specified interface.
inherited
-
toMap(
) → Map< String, Object?> -
Creates an unmodifiable Map from the current IMap instance.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
tryCast<
T extends IUnknown> (T creator(Pointer< COMObject> ), String iid) → T? -
Available on IUnknown, provided by the IUnknownHelpers extension
Tries to cast this COM object to an interface specified iniid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → Object? -
The value for the given
key, ornullifkeyis not in the map.override -
operator []=(
String key, Object? value) → void -
Associates the
keywith the givenvalue.override